@@ -315,9 +315,9 @@ class ProtocolSmartseq3(ProtocolSmartseq):
 
 class ProtocolCapseq(ProtocolFivePrime):
     def __init__(self, merge_method="union", call_peaks=True, call_peaks_method="kde",
-                 label_batches=None, sample_names=None) -> None:
+                 label_batches=None, sample_names=None, annotations=None) -> None:
         super().__init__(merge_method, call_peaks, call_peaks_method, label_batches,
-                         sample_names)
+                         sample_names, annotations)
 
         if self.label_batches is None:
             self.label_batches = False
